@@ -22,27 +22,27 @@ class SoCoPlugin(object):
 
     def __init__(self, soco):
         cls = self.__class__.__name__
-        _LOG.debug('Initializing SoCo plugin %s', cls)
+        _LOG.debug("Initializing SoCo plugin %s", cls)
         self.soco = soco
 
     @property
     def name(self):
         """ human-readable name of the plugin """
-        raise NotImplementedError('Plugins should overwrite the name property')
+        raise NotImplementedError("Plugins should overwrite the name property")
 
     @classmethod
     def from_name(cls, fullname, soco, *args, **kwargs):
         """Instantiate a plugin by its full name."""
 
-        _LOG.debug('Loading plugin %s', fullname)
+        _LOG.debug("Loading plugin %s", fullname)
 
-        parts = fullname.split('.')
-        modname = '.'.join(parts[:-1])
+        parts = fullname.split(".")
+        modname = ".".join(parts[:-1])
         clsname = parts[-1]
 
         mod = importlib.import_module(modname)
         class_ = getattr(mod, clsname)
 
-        _LOG.debug('Loaded class %s', class_)
+        _LOG.debug("Loaded class %s", class_)
 
         return class_(soco, *args, **kwargs)
